#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-FjAkNlC3VAIKX8ZeBFI8Gd
key:                  vector-instances-3.4.3-FjAkNlC3VAIKX8ZeBFI8Gd
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  b83f2a62024e7a94d1860d7d85082e6a
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-FjAkNlC3VAIKX8ZeBFI8Gd
depends:
    base-4.18.2.1 comonad-5.0.9-CVDDRFovdCyBCnhNUM1xFy
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    keys-3.12.5-29BgrwsdEtw5WBUaG8994P
    pointed-5.0.5-Coq5mcmHczR5tQQa4DusSr
    semigroupoids-6.0.2-5KpCoZ3FBsyCetKjS7KKeX
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

